<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <location filename="../src/alert.cpp" line="236"/>
        <source>Close (%1)</source>
        <translation>Закрыть (%1)</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="177"/>
        <source>Collapse</source>
        <translation>Свернуть</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="181"/>
        <source>Expand</source>
        <translation>Развернуть</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <location filename="../src/alert_layer.cpp" line="37"/>
        <source>Dismiss Alert</source>
        <translation>Убрать предупреждение</translation>
    </message>
    <message>
        <location filename="../src/alert_layer.cpp" line="38"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="503"/>
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1% из %Ln минут</numerusform>
            <numerusform>%1% of %Ln minutes</numerusform>
            <numerusform>%1% из %Ln минут</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="505"/>
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1% из %Ln слов</numerusform>
            <numerusform>%1% of %Ln word</numerusform>
            <numerusform>%1% из %Ln слов</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="507"/>
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln слов</numerusform>
            <numerusform>%Ln слов</numerusform>
            <numerusform>%Ln слов</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="509"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln минут</numerusform>
            <numerusform>%Ln минут</numerusform>
            <numerusform>%Ln минут</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/daily_progress.cpp" line="511"/>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="146"/>
        <source>Daily Progress</source>
        <translation>Ежедневный прогресс</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="282"/>
        <source>Longest streak</source>
        <translation>Наиболее долгий период рабочих дней</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="285"/>
        <source>Current streak</source>
        <translation>Текущий период рабочих дней</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="298"/>
        <source>N/A</source>
        <translation>Недоступно</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress_dialog.cpp" line="303"/>
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n дней</numerusform>
            <numerusform>%n days</numerusform>
            <numerusform>%n дней</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="304"/>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <location filename="../src/daily_progress_label.cpp" line="30"/>
        <location filename="../src/daily_progress_label.cpp" line="47"/>
        <source>%1% of daily goal</source>
        <translation>%1% от ежедневной цели</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <location filename="../src/spelling/dictionary_dialog.cpp" line="36"/>
        <source>Set Language</source>
        <translation>Установить язык</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <location filename="../src/document.cpp" line="425"/>
        <source>(Untitled %1)</source>
        <translation>(Без названия %1)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="428"/>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Только чтение)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="492"/>
        <location filename="../src/document.cpp" line="517"/>
        <location filename="../src/document.cpp" line="553"/>
        <location filename="../src/document.cpp" line="559"/>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="492"/>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Невозможно сохранить &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="507"/>
        <source>Save File As</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="517"/>
        <location filename="../src/document.cpp" line="553"/>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Невозможно перезаписать &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="546"/>
        <source>Rename File</source>
        <translation>Переименовать файл</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="559"/>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Невозможно переименовать &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="585"/>
        <source>Reload File?</source>
        <translation>Перезагрузить файл?</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="586"/>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Перезагрузить файл &apos;%1&apos; с диска?</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="587"/>
        <source>All unsaved changes will be lost.</source>
        <translation>Все несохранённые изменения в файле будут утеряны.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="589"/>
        <source>Reload</source>
        <translation>Открыть заново</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1321"/>
        <source>Untitled %1</source>
        <translation>Без названия %1</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1375"/>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1376"/>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Сохранение файла как простой текст приведёт к потере форматирования. Убрать форматирование?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <location filename="../src/document_watcher.cpp" line="189"/>
        <source>File Changed</source>
        <translation>Файл изменён</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="190"/>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Файл &apos;%1&apos; был изменен в другой программе.</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="191"/>
        <source>Do you want to reload the file?</source>
        <translation>Открыть заново этот файл?</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="193"/>
        <source>Reload</source>
        <translation>Открыть заново</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="198"/>
        <source>Ignore</source>
        <translation>Пропустить</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="209"/>
        <source>File Deleted</source>
        <translation>Файл удалён</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="210"/>
        <source>The file %1 was deleted by another program.</source>
        <translation>Файл %1 был удалён другой программой.</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="211"/>
        <source>Do you want to save or close the file?</source>
        <translation>Хотите ли вы сохранить файл, или же закрыть его?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <location filename="../src/fileformats/docx_reader.cpp" line="94"/>
        <source>Unable to open archive.</source>
        <translation>Невозможно открыть архив.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <location filename="../src/find_dialog.cpp" line="47"/>
        <source>Search for:</source>
        <translation>Найти:</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="49"/>
        <source>Replace with:</source>
        <translation>Заменить на:</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="53"/>
        <source>Ignore case</source>
        <translation>Не учитывать регистр</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="54"/>
        <source>Whole words only</source>
        <translation>Только слова целиком</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="55"/>
        <source>Regular expressions</source>
        <translation>Регулярные выражения</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="58"/>
        <source>Search up</source>
        <translation>Найти выше</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="59"/>
        <source>Search down</source>
        <translation>Найти ниже</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="66"/>
        <source>&amp;Find</source>
        <translation>&amp;Найти</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="70"/>
        <source>&amp;Replace</source>
        <translation>&amp;Заменить</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="74"/>
        <source>Replace &amp;All</source>
        <translation>Заменить &amp;все</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="151"/>
        <source>Find</source>
        <translation>Найти</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="159"/>
        <source>Replace</source>
        <translation>Заменить</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/find_dialog.cpp" line="275"/>
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Заменить %n совпадение?</numerusform>
            <numerusform>Заменить %n совпадения?</numerusform>
            <numerusform>Заменить %n совпадений?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="275"/>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="279"/>
        <location filename="../src/find_dialog.cpp" line="354"/>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="279"/>
        <location filename="../src/find_dialog.cpp" line="354"/>
        <source>Phrase not found.</source>
        <translation>Фраза не найдена.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="71"/>
        <source>OpenDocument Text</source>
        <translation>Открытый Текстовый Документ</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="73"/>
        <source>Office Open XML</source>
        <translation>Открытый офисный файл XML</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="75"/>
        <source>Rich Text Format</source>
        <translation>Расширенный Текстовый формат</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="77"/>
        <source>Plain Text</source>
        <translation>Обычный текст</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="92"/>
        <source>All Files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="106"/>
        <source>All Supported Files</source>
        <translation>Все поддерживаемые файлы</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="54"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="55"/>
        <source>Check Spelling...</source>
        <translation>Проверить правописание...</translation>
    </message>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="129"/>
        <source>(No suggestions found)</source>
        <translation>(Нет вариантов)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <location filename="../src/image_button.cpp" line="100"/>
        <source>Open Image</source>
        <translation>Открыть изображение</translation>
    </message>
    <message>
        <location filename="../src/image_button.cpp" line="100"/>
        <source>Images(%1)</source>
        <translation>Изображения(%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="51"/>
        <source>Select application language:</source>
        <translation>Выберите язык приложения:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="54"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Язык системы&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="189"/>
        <source>Note</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="189"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Перезапустите программу, чтобы применить изменение языка.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <location filename="../src/fileformats/odt_reader.cpp" line="68"/>
        <source>Unable to open archive.</source>
        <translation>Невозможно открыть архив.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="109"/>
        <source>Preferences</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="112"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="114"/>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="116"/>
        <source>Toolbar</source>
        <translation>Панель инструментов</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="115"/>
        <source>Spell Checking</source>
        <translation>Проверка правописания</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="453"/>
        <source>Select Dictionary</source>
        <translation>Выберите словарь</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="467"/>
        <location filename="../src/preferences_dialog.cpp" line="570"/>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="467"/>
        <source>Unable to open archive.</source>
        <translation>Невозможно открыть архив.</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="570"/>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Архив не содержит правильного словаря.</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="256"/>
        <location filename="../src/preferences_dialog.cpp" line="395"/>
        <location filename="../src/preferences_dialog.cpp" line="558"/>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="117"/>
        <source>Shortcuts</source>
        <translation>Комбинация клавиш</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="257"/>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Некоторые комбинации клавиш совпадают. Продолжить?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="558"/>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Словарь &quot;%1&quot; уже существует. Перезаписать его?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="113"/>
        <source>Daily Goal</source>
        <translation>Дневная задача</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="793"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="795"/>
        <source>Minutes:</source>
        <translation>Минут:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="802"/>
        <location filename="../src/preferences_dialog.cpp" line="912"/>
        <source>Words:</source>
        <translation>Слов:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="705"/>
        <source>Editing</source>
        <translation>Редактирование</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="707"/>
        <source>Always vertically center</source>
        <translation>Всегда центрировать по вертикали</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="708"/>
        <source>Block insertion cursor</source>
        <translation>Прямоугольный курсор</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="709"/>
        <source>Smooth fonts</source>
        <translation>Сглаживать шрифты</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="710"/>
        <source>Typewriter sounds</source>
        <translation>Звук пишущей машинки</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="712"/>
        <source>Smart quotes:</source>
        <translation>Заменять кавычки:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="719"/>
        <source>Double</source>
        <translation>Двойные</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="720"/>
        <source>Single</source>
        <translation>Одинарные</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="741"/>
        <source>Scenes</source>
        <translation>Сцены</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="748"/>
        <source>Divider:</source>
        <translation>Разделительная линия:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="751"/>
        <source>Saving</source>
        <translation>Сохранение</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="753"/>
        <source>Automatically save changes</source>
        <translation>Автоматически сохранять изменения</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="754"/>
        <source>Remember cursor position</source>
        <translation>Запоминать позицию курсора</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="872"/>
        <source>Word count</source>
        <translation>Количество слов</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="873"/>
        <source>Page count</source>
        <translation>Количество страниц</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="874"/>
        <source>Paragraph count</source>
        <translation>Количество абзацев</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="875"/>
        <source>Character count</source>
        <translation>Количество символов</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="898"/>
        <source>Characters:</source>
        <translation>Символов:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="905"/>
        <source>Paragraphs:</source>
        <translation>Абзацев:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="884"/>
        <source>Word Count Algorithm</source>
        <translation>Алгоритм подсчёта слов</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="396"/>
        <source>Reset daily progress for today to zero?</source>
        <translation>Сбросить сегодняшний ежедневный прогресс на ноль?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="755"/>
        <source>Write byte order mark in plain text files</source>
        <translation>Записывать метку байта в простых текстовых файлах</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="757"/>
        <source>Default format:</source>
        <translation>Формат по умолчанию:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="818"/>
        <source>Reset Today</source>
        <translation>Сбросить сегодняшнее</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="831"/>
        <source>History</source>
        <translation>История</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="833"/>
        <source>Remember history</source>
        <translation>Запоминать историю</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="836"/>
        <source>Show streaks</source>
        <translation>Показывать рабочие дни</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="851"/>
        <source>Minimum progress for streaks:</source>
        <translation>Минимальный прогресс для зачета дня в рабочий период:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="886"/>
        <source>Detect word boundaries</source>
        <translation>Определять границы слов</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="887"/>
        <source>Divide character count by six</source>
        <translation>Делить количество символов на шесть</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="888"/>
        <source>Count each letter as a word</source>
        <translation>Считать каждую букву, как слово</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="896"/>
        <source>Page Count Algorithm</source>
        <translation>Алгоритм формирования страницы</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1039"/>
        <source>Style</source>
        <translation>Стиль</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1042"/>
        <source>Icons Only</source>
        <translation>Только значки</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1043"/>
        <source>Text Only</source>
        <translation>Только текст</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1044"/>
        <source>Text Alongside Icons</source>
        <translation>Текст рядом со значками</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1045"/>
        <source>Text Under Icons</source>
        <translation>Текст под значками</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1049"/>
        <source>Text Position:</source>
        <translation>Положение текста:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1052"/>
        <source>Actions</source>
        <translation>Действия</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1068"/>
        <source>Move Up</source>
        <translation>Переместить вверх</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1070"/>
        <source>Move Down</source>
        <translation>Переместить вниз</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1072"/>
        <source>Add Separator</source>
        <translation>Добавить разделитель</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Shortcut</source>
        <translation>Комбинация клавиш</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="959"/>
        <source>Check spelling as you type</source>
        <translation>Проверять орфографию при вводе</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="960"/>
        <source>Ignore words in UPPERCASE</source>
        <translation>Пропускать слова в ВЕРХНЕМ РЕГИСТРЕ</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="961"/>
        <source>Ignore words with numbers</source>
        <translation>Пропускать слова с цифрами</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="974"/>
        <source>Language</source>
        <translation>Язык</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="978"/>
        <location filename="../src/preferences_dialog.cpp" line="999"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1011"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="994"/>
        <source>Personal Dictionary</source>
        <translation>Пользовательский словарь</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <location filename="../src/fileformats/rtf_reader.cpp" line="209"/>
        <location filename="../src/fileformats/rtf_reader.cpp" line="213"/>
        <source>Not a supported RTF file.</source>
        <translation>Неподдерживаемый файл RTF.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <location filename="../src/fileformats/rtf_tokenizer.cpp" line="151"/>
        <source>Unexpectedly reached end of file.</source>
        <translation>Неожиданный конец файла.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <location filename="../src/scene_list.cpp" line="89"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Стрелка вниз</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="94"/>
        <source>Move Scenes Up</source>
        <translation>Передвинуть сцены выше</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="95"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Стрелка вверх</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="115"/>
        <source>Toggle Scene List</source>
        <translation>Открыть/закрыть список сцен</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="116"/>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="399"/>
        <source>Show scene list (%1)</source>
        <translation>Показать список сцен (%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="400"/>
        <source>Hide scene list (%1)</source>
        <translation>Скрыть список сцен (%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="147"/>
        <source>Filter</source>
        <translation>Фильтровать</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="88"/>
        <source>Move Scenes Down</source>
        <translation>Передвинуть сцены ниже</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="155"/>
        <source>Resize scene list</source>
        <translation>Изменить размер списка сцен</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../src/session.cpp" line="43"/>
        <location filename="../src/session_manager.cpp" line="57"/>
        <location filename="../src/session_manager.cpp" line="428"/>
        <location filename="../src/session_manager.cpp" line="451"/>
        <location filename="../src/session_manager.cpp" line="460"/>
        <location filename="../src/session_manager.cpp" line="461"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <location filename="../src/session_manager.cpp" line="52"/>
        <source>Manage Sessions</source>
        <translation>Управление сеансами</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="83"/>
        <source>S&amp;essions</source>
        <translation>С&amp;еансы</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="97"/>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="100"/>
        <source>Duplicate</source>
        <translation>Дублировать</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="103"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="106"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="109"/>
        <source>Switch To</source>
        <translation>Переключиться</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="220"/>
        <source>New Session</source>
        <translation>Новый сеанс</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="279"/>
        <source>Duplicate Session</source>
        <translation>Дублировать сессию</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="324"/>
        <source>Rename Session</source>
        <translation>Переименовать сеанс</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="351"/>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="351"/>
        <source>Delete selected session?</source>
        <translation>Удалить выбранный сеанс?</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="423"/>
        <source>Session name:</source>
        <translation>Название сеанса:</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="431"/>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="431"/>
        <source>The requested session name is already in use.</source>
        <translation>Заданное имя сеанса уже используется.</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="487"/>
        <source>&amp;New...</source>
        <translation>&amp;Новый...</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="487"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="488"/>
        <source>&amp;Manage...</source>
        <translation>&amp;Управление...</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="488"/>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="126"/>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="129"/>
        <source>Reset to Default</source>
        <translation>Сбросить к значениям по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1149"/>
        <location filename="../src/symbols_dialog.cpp" line="219"/>
        <source>Shortcut:</source>
        <translation>Комбинация клавиш:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <location filename="../src/smart_quotes.cpp" line="150"/>
        <source>Replacing quotation marks...</source>
        <translation>Замена кавычек...</translation>
    </message>
    <message>
        <location filename="../src/smart_quotes.cpp" line="151"/>
        <source>Please Wait</source>
        <translation>Пожалуйста, подождите</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="134"/>
        <source>Check Spelling</source>
        <translation>Проверить орфографию</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="142"/>
        <source>&amp;Add</source>
        <translation>&amp;Добавить</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="145"/>
        <source>&amp;Ignore</source>
        <translation>&amp;Пропустить</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="148"/>
        <source>I&amp;gnore All</source>
        <translation>П&amp;ропустить все</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="153"/>
        <source>&amp;Change</source>
        <translation>&amp;Заменить</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="156"/>
        <source>C&amp;hange All</source>
        <translation>Заме&amp;нить все</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="171"/>
        <source>Not in dictionary:</source>
        <translation>Нет в словаре:</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="179"/>
        <source>Change to:</source>
        <translation>Заменить на:</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="195"/>
        <source>Checking spelling...</source>
        <translation>Проверяется орфография...</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="195"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="196"/>
        <source>Please wait</source>
        <translation>Пожалуйста, подождите</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="223"/>
        <source>Continue checking at beginning of file?</source>
        <translation>Продолжить проверку с начала файла?</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="282"/>
        <source>Spell check complete.</source>
        <translation>Проверка орфографии завершена.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="96"/>
        <source>Symbols</source>
        <translation>Символы</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="103"/>
        <source>Recently used symbols</source>
        <translation>Недавно использованные символы</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="133"/>
        <source>All symbols</source>
        <translation>Все символы</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="195"/>
        <source>Details</source>
        <translation>Подробности</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="221"/>
        <source>Name:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="231"/>
        <source>Insert</source>
        <translation>Вставить</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Blocks</source>
        <translation>Блоки</translation>
    </message>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Scripts</source>
        <translation>Скрипты</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <location filename="../src/theme.cpp" line="103"/>
        <source>Untitled %1</source>
        <translation>Безымянная %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <location filename="../src/theme_dialog.cpp" line="103"/>
        <source>Name:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>No Image</source>
        <translation>Нет изображения</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Tiled</source>
        <translation>Замостить</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Centered</source>
        <translation>Центрировать</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Stretched</source>
        <translation>По ширине</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Scaled</source>
        <translation>Масштабировать</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Zoomed</source>
        <translation>Приблизить</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="211"/>
        <source>Opacity:</source>
        <translation>Непрозрачность:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="212"/>
        <source>Position:</source>
        <translation>Позиция:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="213"/>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="217"/>
        <source>Round Text Background Corners</source>
        <translation>Закругление углов фона текста</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="231"/>
        <location filename="../src/theme_dialog.cpp" line="249"/>
        <location filename="../src/theme_dialog.cpp" line="279"/>
        <source>Radius:</source>
        <translation>Радиус:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="235"/>
        <source>Blur Text Background</source>
        <translation>Размытие фона текста</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="253"/>
        <source>Text Background Drop Shadow</source>
        <translation>Падающая тень от текста</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="280"/>
        <source>Vertical Offset:</source>
        <translation>Вертикальное смещение:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="284"/>
        <source>Margins</source>
        <translation>Границы</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="302"/>
        <source>Window:</source>
        <translation>Окно:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="303"/>
        <source>Page:</source>
        <translation>Страница:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="361"/>
        <source>Indent first line</source>
        <translation>Отступ первой строки:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="368"/>
        <source>Above:</source>
        <translation>Перед:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="369"/>
        <source>Below:</source>
        <translation>После:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="160"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="93"/>
        <source>Edit Theme</source>
        <translation>Редактировать тему</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="150"/>
        <source>Window Background</source>
        <translation>Фон окна</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="178"/>
        <location filename="../src/theme_dialog.cpp" line="332"/>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="144"/>
        <location filename="../src/theme_dialog.cpp" line="176"/>
        <location filename="../src/theme_dialog.cpp" line="210"/>
        <location filename="../src/theme_dialog.cpp" line="278"/>
        <source>Color:</source>
        <translation>Цвет:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="177"/>
        <source>Image:</source>
        <translation>Изображение:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="202"/>
        <location filename="../src/theme_dialog.cpp" line="224"/>
        <location filename="../src/theme_dialog.cpp" line="242"/>
        <location filename="../src/theme_dialog.cpp" line="264"/>
        <location filename="../src/theme_dialog.cpp" line="271"/>
        <location filename="../src/theme_dialog.cpp" line="288"/>
        <location filename="../src/theme_dialog.cpp" line="295"/>
        <location filename="../src/theme_dialog.cpp" line="344"/>
        <location filename="../src/theme_dialog.cpp" line="350"/>
        <location filename="../src/theme_dialog.cpp" line="356"/>
        <source> pixels</source>
        <translation> пикселей</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="182"/>
        <source>Text Background</source>
        <translation>Фон текста</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="116"/>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="145"/>
        <source>Font:</source>
        <translation>Шрифт:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="146"/>
        <source>Misspelled:</source>
        <translation>Ошибки:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="307"/>
        <source>Line Spacing</source>
        <translation>Межстрочный интервал</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Single</source>
        <translation>Одинарный</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>1.5 Lines</source>
        <translation>Полуторный</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Double</source>
        <translation>Двойной</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Proportional</source>
        <translation>Пропорциональный</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="333"/>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="341"/>
        <source>Paragraph Spacing</source>
        <translation>Отступы параграфа</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="367"/>
        <source>Tab Width:</source>
        <translation>Ширина вкладки:</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="253"/>
        <source>New Theme</source>
        <translation>Новая тема</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <location filename="../src/theme_manager.cpp" line="78"/>
        <source>Themes</source>
        <translation>Темы</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="92"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="107"/>
        <source>Gentle Blues</source>
        <translation>Нежный блюз</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="108"/>
        <source>Old School</source>
        <translation>Старая школа</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="109"/>
        <source>Space Dreams</source>
        <translation>Космические мечты</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="110"/>
        <source>Writing Desk</source>
        <translation>Письменный стол</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="113"/>
        <location filename="../src/theme_manager.cpp" line="174"/>
        <source>New</source>
        <translation>Новая</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="117"/>
        <location filename="../src/theme_manager.cpp" line="178"/>
        <source>Duplicate</source>
        <translation>Дублировать</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="131"/>
        <source>Custom</source>
        <translation>Пользовательская</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="183"/>
        <source>Edit</source>
        <translation>Редактировать</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="188"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="193"/>
        <source>Import</source>
        <translation>Импорт</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="197"/>
        <source>Export</source>
        <translation>Экспорт</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="311"/>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="311"/>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Удалить тему &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="339"/>
        <location filename="../src/theme_manager.cpp" line="416"/>
        <source>Themes (%1)</source>
        <translation>Темы (%1)</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="339"/>
        <source>Import Theme</source>
        <translation>Импортировать тему</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="416"/>
        <source>Export Theme</source>
        <translation>Экспортировать тему</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <location filename="../src/timer.cpp" line="255"/>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Delete timer?</source>
        <translation>Удалить таймер?</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="355"/>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Слов:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="356"/>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Страниц:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="357"/>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Абзацев:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="358"/>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Символов:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="402"/>
        <source>Set Delay</source>
        <translation>Интервал</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="403"/>
        <source>Set Time</source>
        <translation>Заданное время</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="406"/>
        <source>Delay:</source>
        <translation>Интервал:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="409"/>
        <source>Time:</source>
        <translation>Время:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="418"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="431"/>
        <source>Alarm</source>
        <translation>Будильник</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="444"/>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="448"/>
        <source>Memo:</source>
        <translation>Сообщение:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="459"/>
        <source>Edit</source>
        <translation>Редактировать</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="461"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <location filename="../src/timer_display.cpp" line="150"/>
        <source>HH:mm:ss</source>
        <translation>ЧЧ:мм:сс</translation>
    </message>
    <message>
        <location filename="../src/timer_display.cpp" line="160"/>
        <source>No timers running</source>
        <translation>Таймер не включён</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <location filename="../src/timer_manager.cpp" line="46"/>
        <source>Timers</source>
        <translation>Таймеры</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="78"/>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="83"/>
        <source>Recent</source>
        <translation>Недавний</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Cancel editing timers?</source>
        <translation>Отменить редактирование таймеров?</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="316"/>
        <source>+HH:mm:ss</source>
        <translation>+ЧЧ:мм:сс</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="323"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="300"/>
        <source>Loading themes</source>
        <translation>Загружаются темы</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1146"/>
        <source>Loading sounds</source>
        <translation>Загружаются звуки</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="309"/>
        <location filename="../src/window.cpp" line="1065"/>
        <source>Untitled</source>
        <translation>Безымянный</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="682"/>
        <source>Open File</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="864"/>
        <source>About FocusWriter</source>
        <translation>О программе FocusWriter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="867"/>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="868"/>
        <source>A simple fullscreen word processor</source>
        <translation>Простой полноэкранный текстовый редактор</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="869"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="870"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Выпущен под лицензией &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="871"/>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>В программе используются иконки из темы &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="872"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Используются согласно лицензии &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <location filename="../src/window.cpp" line="928"/>
        <source>Characters: %L1 / %L2</source>
        <translation>Символов: %L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="172"/>
        <location filename="../src/window.cpp" line="929"/>
        <source>Pages: %L1</source>
        <translation>Страниц: %L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <location filename="../src/window.cpp" line="930"/>
        <source>Paragraphs: %L1</source>
        <translation>Абзацев: %L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <location filename="../src/window.cpp" line="931"/>
        <source>Words: %L1</source>
        <translation>Слов: %L1</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="602"/>
        <location filename="../src/window.cpp" line="1020"/>
        <source>Opening %1</source>
        <translation>Открывается %1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="332"/>
        <source>(Untitled %1)</source>
        <translation>(Безымянный %1)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="207"/>
        <source>List all documents</source>
        <translation>Список всех документов</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="210"/>
        <source>Switch to Next Document</source>
        <translation>Перейти к следующему документу</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="216"/>
        <source>Switch to Previous Document</source>
        <translation>Перейти к предыдущему документу</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>Switch to First Document</source>
        <translation>Перейти к первому документу</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="228"/>
        <source>Switch to Last Document</source>
        <translation>Перейти к последнему документу</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="236"/>
        <source>Switch to Document %1</source>
        <translation>Перейти к документу %1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="296"/>
        <source>Loading settings</source>
        <translation>Загружаются настройки</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="318"/>
        <source>Emergency cache is not writable.</source>
        <translation>Резервная память недоступна для записи.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="338"/>
        <location filename="../src/window.cpp" line="1034"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="339"/>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>Работа приложения была завершена неправильно.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="340"/>
        <source>Restore from the emergency cache?</source>
        <translation>Восстановить открытые файлы из резервной памяти?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="467"/>
        <source>Some files could not be opened.</source>
        <translation>Не удалось открыть некоторые файлы.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="470"/>
        <source>Some files were opened Read-Only.</source>
        <translation>Некоторые файлы были открыты только для чтения.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1035"/>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; новее резервной копии.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1036"/>
        <source>Overwrite newer file?</source>
        <translation>Заменить новую версию резервной копией?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1121"/>
        <source>Save Changes?</source>
        <translation>Сохранить изменения?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1122"/>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Сохранить изменения в файле &apos;%1&apos; перед закрытием?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1123"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Ваши изменения будут утеряны, если вы не сохраните их.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1153"/>
        <source>Unable to load typewriter sounds.</source>
        <translation>Не удаётся загрузить звук пишущей машинки.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1154"/>
        <source>Please make sure that SDL_mixer is installed.</source>
        <translation>Проверьте, установлен ли пакет SDL_mixer.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1290"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1291"/>
        <source>&amp;New</source>
        <translation>&amp;Новый</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1292"/>
        <source>&amp;Open...</source>
        <translation>&amp;Открыть...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1293"/>
        <source>Reloa&amp;d</source>
        <translation>Откр&amp;ыть заново</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1295"/>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1297"/>
        <source>Save &amp;As...</source>
        <translation>Сохранить &amp;как...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1298"/>
        <source>&amp;Rename...</source>
        <translation>П&amp;ереименовать...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1300"/>
        <source>Save A&amp;ll</source>
        <translation>Сохранить вс&amp;е</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1303"/>
        <source>Manage Sessions</source>
        <translation>Управление сеансами</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1305"/>
        <source>New Session</source>
        <translation>Новый сеанс</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1308"/>
        <source>&amp;Print...</source>
        <translation>&amp;Печать...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1310"/>
        <source>&amp;Close</source>
        <translation>З&amp;акрыть</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1311"/>
        <source>&amp;Quit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1311"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1315"/>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1316"/>
        <source>&amp;Undo</source>
        <translation>&amp;Отменить</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1319"/>
        <source>&amp;Redo</source>
        <translation>Пов&amp;торить</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1323"/>
        <source>Cu&amp;t</source>
        <translation>Вы&amp;резать</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1326"/>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1329"/>
        <source>&amp;Paste</source>
        <translation>Вс&amp;тавить</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1330"/>
        <source>Paste &amp;Unformatted</source>
        <translation>Вставить без &amp;форматирования</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1330"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1332"/>
        <source>Select &amp;All</source>
        <translation>&amp;Выбрать всё</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>Select &amp;Scene</source>
        <translation>Выбрать &amp;сцену</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1336"/>
        <source>Fo&amp;rmat</source>
        <translation>Ф&amp;ормат</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1338"/>
        <source>&amp;Bold</source>
        <translation>Полу&amp;жирный</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1340"/>
        <source>&amp;Italic</source>
        <translation>&amp;Курсив</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1342"/>
        <source>&amp;Underline</source>
        <translation>Под&amp;чёркнутый</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1344"/>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Зачёркнутый</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1344"/>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1346"/>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Надстрочный индекс</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1346"/>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1348"/>
        <source>&amp;Subscript</source>
        <translation>П&amp;одстрочный индекс</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1348"/>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Align &amp;Left</source>
        <translation>По &amp;левому краю</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1354"/>
        <source>Align &amp;Center</source>
        <translation>По &amp;центру</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1354"/>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1356"/>
        <source>Align &amp;Right</source>
        <translation>По &amp;правому краю</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1356"/>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1358"/>
        <source>Align &amp;Justify</source>
        <translation>По &amp;ширине</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1358"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>&amp;Decrease Indent</source>
        <translation>У&amp;меньшить отступ</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1369"/>
        <source>I&amp;ncrease Indent</source>
        <translation>У&amp;величить отступ</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1369"/>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1372"/>
        <source>Le&amp;ft to Right Block</source>
        <translation>Фрагмент слева напр&amp;аво</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1374"/>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Фрагмент справа нал&amp;ево</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1382"/>
        <source>&amp;Tools</source>
        <translation>&amp;Инструменты</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1383"/>
        <source>&amp;Find...</source>
        <translation>&amp;Найти...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1384"/>
        <source>Find &amp;Next</source>
        <translation>Найти следующ&amp;ий</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1387"/>
        <source>Find Pre&amp;vious</source>
        <translation>Найти пред&amp;ыдущий</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>&amp;Replace...</source>
        <translation>За&amp;менить...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1392"/>
        <source>Smart &amp;Quotes</source>
        <translation>Заменить кавы&amp;чки</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1393"/>
        <source>Update &amp;Document</source>
        <translation>Во всём &amp;документе</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1396"/>
        <source>Update &amp;Selection</source>
        <translation>В &amp;выделенном</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1400"/>
        <source>&amp;Spelling...</source>
        <translation>Ор&amp;фография...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1400"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1401"/>
        <source>Set &amp;Language...</source>
        <translation>Установить &amp;язык...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1403"/>
        <source>&amp;Timers...</source>
        <translation>&amp;Таймеры...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1404"/>
        <source>S&amp;ymbols...</source>
        <translation>Сим&amp;волы...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1405"/>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Ежедневный прогресс</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1408"/>
        <source>&amp;Settings</source>
        <translation>&amp;Параметры</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1409"/>
        <source>Show &amp;Toolbar</source>
        <translation>Показать панель &amp;инструментов</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1414"/>
        <source>Show &amp;Menu Icons</source>
        <translation>Показать значки мен&amp;ю</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1420"/>
        <source>F&amp;ocused Text</source>
        <translation>Подсве&amp;тка текста</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>&amp;Fullscreen</source>
        <translation>Полно&amp;экранный режим</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1424"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1428"/>
        <source>M&amp;inimize</source>
        <translation>Сверн&amp;уть</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1428"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1430"/>
        <source>&amp;Themes...</source>
        <translation>&amp;Темы...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1433"/>
        <source>&amp;Preferences...</source>
        <translation>Пара&amp;метры...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1439"/>
        <source>Focus Off</source>
        <translation>Отключена</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1441"/>
        <source>Focus One Line</source>
        <translation>На одной строке</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1443"/>
        <source>Focus Three Lines</source>
        <translation>На трёх строках</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1444"/>
        <source>&amp;Paragraph</source>
        <translation>&amp;На абзаце</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1445"/>
        <source>Focus Paragraph</source>
        <translation>На абзаце</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1454"/>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1459"/>
        <source>&amp;Help</source>
        <translation>Спр&amp;авка</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1432"/>
        <source>Application &amp;Language...</source>
        <translation>&amp;Язык приложения...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="400"/>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Формат некоторых файлов не поддерживается программой. Эти файлы не были открыты.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1438"/>
        <source>&amp;Off</source>
        <translation>&amp;Выключено</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1440"/>
        <source>One &amp;Line</source>
        <translation>Одна ст&amp;рока</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1442"/>
        <source>&amp;Three Lines</source>
        <translation>&amp;Три строки</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1460"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1468"/>
        <source>About &amp;Qt</source>
        <translation>Информация о &amp;Qt</translation>
    </message>
</context>
</TS>
